=======
Credits
=======

Maintainer
----------

* `Anthony Fullam <https://github.com/fullama>`_

Contributors
------------

* `Askarbek Orakov <https://github.com/Askarbek-orakov>`_
* `Sebastian Schmidt <https://github.com/defleury>`_
* `Luis Pedro Coelho <https://github.com/luispedro>`_
